summaryrefslogtreecommitdiff
path: root/ace/Connector.cpp
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>1997-05-24 19:18:23 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>1997-05-24 19:18:23 +0000
commitfc0738da5a027a757820f808bde7748d23436f2c (patch)
tree964d55f15fb323d791e493aa17ef43e7b76f3cde /ace/Connector.cpp
parent5df999be5fa83216df024a21687a92e1478f592f (diff)
downloadATCD-fc0738da5a027a757820f808bde7748d23436f2c.tar.gz
*** empty log message ***
Diffstat (limited to 'ace/Connector.cpp')
-rw-r--r--ace/Connector.cpp13
1 files changed, 10 insertions, 3 deletions
diff --git a/ace/Connector.cpp b/ace/Connector.cpp
index 2ab0ec98708..a5f405de623 100644
--- a/ace/Connector.cpp
+++ b/ace/Connector.cpp
@@ -361,9 +361,16 @@ ACE_Connector<SH, PR_CO_2>::connect (SH *&sh,
this->create_AST (sh, synch_options);
}
else
- // Make sure to close down the Channel to avoid descriptor
- // leaks.
- sh->close (0);
+ {
+ // Make sure to save/restore the errno since <close> may
+ // change it.
+
+ int error = errno;
+ // Make sure to close down the Channel to avoid descriptor
+ // leaks.
+ sh->close (0);
+ errno = error;
+ }
return -1;
}
else